Tutorial 2: Understanding Fit Results
======================================

.. deprecated::
   This tutorial has been superseded by the structured tutorial guide.

See :doc:`/tutorials/routine/getting_started/understanding_results` for the updated version.
